require "import"
import "android.app.*"
import "android.widget.*"
import "android.view.*"
import "android.text.InputType"
import "android.graphics.Color"
import "java.io.*"
import "android.os.Environment"
import "android.graphics.pdf.PdfDocument"
import "android.net.Uri"
import "android.graphics.Paint"
import "android.content.Intent" -- استيراد Intent بشكل صريح
import "android.content.Context" -- استيراد Context إذا كان مطلوبًا

-- Function to create the dialog
function createDialog(context)
    -- Creating a layout for the dialog window
    local linearLayout = LinearLayout(context)
    linearLayout.setOrientation(LinearLayout.VERTICAL)
    linearLayout.setBackgroundColor(Color.BLACK)

    -- Button identifiers
    local BUTTON_TEXT_TO_PDF = 1
    local BUTTON_TELEGRAM_CHANNEL = 2
    local BUTTON_EXIT = 3

    -- Creating buttons
    function createButton(text, id)
        local button = Button(context)
        button.setText(text)
        button.setId(id)
        button.setBackgroundColor(Color.RED)
        button.setTextColor(Color.BLACK)
        return button
    end

    -- Button to convert text to PDF
    local btnTextToPdf = createButton("Convert Text to PDF", BUTTON_TEXT_TO_PDF)

    -- Button to join my telegram Channel 
    local btnTelegramChannel = createButton("Access Developer's Channel", BUTTON_TELEGRAM_CHANNEL)

    -- Exit button
    local btnExit = createButton("Exit", BUTTON_EXIT)

    -- Adding buttons to the layout
    linearLayout.addView(btnTextToPdf)
    linearLayout.addView(btnTelegramChannel)
    linearLayout.addView(btnExit)

    -- Creating the dialog window
    local alertDialog = LuaDialog(context)
    alertDialog.setTitle("Convert to PDF")
    alertDialog.setView(linearLayout)
    alertDialog.setCancelable(true)

    -- Adding actions to buttons
    function handleButtonClick(view)
        local id = view.getId()
        if id == BUTTON_TEXT_TO_PDF then
            -- Show window to convert text to PDF
            showTextToPdfDialog(context)
        elseif id == BUTTON_TELEGRAM_CHANNEL then
            -- join my Telegram Channel  on Telegram
            openTelegramChannel(context)
            alertDialog.dismiss()
        elseif id == BUTTON_EXIT then
            -- Close the dialog window
            alertDialog.dismiss()
        end
    end

    btnTextToPdf.setOnClickListener(handleButtonClick)
    btnTelegramChannel.setOnClickListener(handleButtonClick)
    btnExit.setOnClickListener(handleButtonClick)

    -- Show the dialog window
    alertDialog.show()
end

function openTelegramChannel(context)
    -- محاولة فتح القناة على تليجرام
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse("https://t.me/AndroidTechnologyForTheBlind"))
    context.startActivity(intent)
end

function showTextToPdfDialog(context)
    -- Creating a layout for the dialog window
    local linearLayout = LinearLayout(context)
    linearLayout.setOrientation(LinearLayout.VERTICAL)
    linearLayout.setBackgroundColor(Color.BLACK)

    -- Creating input fields
    local inputFileName = EditText(context)
    inputFileName.setHint("File Name")
    inputFileName.setInputType(InputType.TYPE_CLASS_TEXT)
    inputFileName.setLayoutParams(LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, LinearLayout.LayoutParams.WRAP_CONTENT))

    local scrollView = ScrollView(context)
    local inputContent = EditText(context)
    inputContent.setHint("File content")
    inputContent.setInputType(InputType.TYPE_CLASS_TEXT + InputType.TYPE_TEXT_FLAG_MULTI_LINE)
    inputContent.setLayoutParams(LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, 200)) -- Fixed size

    scrollView.addView(inputContent)

    -- Adding input fields to the layout
    linearLayout.addView(inputFileName)
    linearLayout.addView(scrollView)

    -- Creating buttons
    local btnConvert = Button(context)
    btnConvert.setText("Convert to PDF")
    btnConvert.setBackgroundColor(Color.RED)
    btnConvert.setTextColor(Color.BLACK)

    local btnBack = Button(context)
    btnBack.setText("Back")
    btnBack.setBackgroundColor(Color.RED)
    btnBack.setTextColor(Color.BLACK)

    -- Adding buttons to the layout
    linearLayout.addView(btnConvert)
    linearLayout.addView(btnBack)

    -- Creating the dialog window
    local alertDialog = LuaDialog(context)
    alertDialog.setTitle("Convert Text to PDF")
    alertDialog.setView(linearLayout)
    alertDialog.setCancelable(true)

    -- Function to convert text to PDF and save it in the Downloads folder
    function convertTextToPdf(content, fileName)
        local pdfDocument = PdfDocument()
        local pageInfo = PdfDocument.PageInfo.Builder(595, 842, 1).create()
        local page = pdfDocument.startPage(pageInfo)
        local canvas = page.getCanvas()
        local paint = Paint()

        paint.setColor(Color.BLACK)
        paint.setTextSize(12)
        local lines = content:split("\n")
        local y = 20
        for i, line in ipairs(lines) do
            canvas.drawText(line, 10, y, paint)
            y = y + 15
            if y > 800 then
                pdfDocument.finishPage(page)
                pageInfo = PdfDocument.PageInfo.Builder(595, 842, i + 1).create()
                page = pdfDocument.startPage(pageInfo)
                canvas = page.getCanvas()
                y = 20
            end
        end
        pdfDocument.finishPage(page)

        local downloadsDir = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS).getPath()
        local file = File(downloadsDir, fileName .. ".pdf")

        local outputStream = FileOutputStream(file)
        pdfDocument.writeTo(outputStream)
        pdfDocument.close()
        outputStream.close()

        return file.getPath()
    end

    -- Adding a confirmation message and close button
    function showConfirmationDialog(context, message)
        -- Creating a layout for the dialog window
        local confirmationLayout = LinearLayout(context)
        confirmationLayout.setOrientation(LinearLayout.VERTICAL)
        confirmationLayout.setBackgroundColor(Color.BLACK)

        -- Creating the confirmation message
        local confirmationMessage = TextView(context)
        confirmationMessage.setText(message)
        confirmationMessage.setTextColor(Color.WHITE)
        confirmationMessage.setPadding(20, 20, 20, 20)
        confirmationLayout.addView(confirmationMessage)

        -- Creating the close button
        local btnClose = Button(context)
        btnClose.setText("Close")
        btnClose.setBackgroundColor(Color.RED)
        btnClose.setTextColor(Color.BLACK)
        confirmationLayout.addView(btnClose)

        -- Creating the dialog window
        local confirmationDialog = LuaDialog(context)
        confirmationDialog.setTitle("Converted")
        confirmationDialog.setView(confirmationLayout)
        confirmationDialog.setCancelable(true)

        btnClose.setOnClickListener(function(view)
            confirmationDialog.dismiss()
        end)

        -- Show the dialog window
        confirmationDialog.show()
    end

    -- Adding actions to buttons
    btnConvert.setOnClickListener(function(view)
        local content = inputContent.getText().toString()
        local fileName = inputFileName.getText().toString()

        -- Convert text to PDF and save it in the Downloads folder
        local filePath = convertTextToPdf(content, fileName)

        -- Show confirmation message
        showConfirmationDialog(context, "The file is saved at: " .. filePath)
    end)

    btnBack.setOnClickListener(function(view)
        -- Close the dialog window and go back
        alertDialog.dismiss()
    end)

    -- Show the dialog window
    alertDialog.show()
end

-- Using a robust function to split text into lines
string.split = function(inputstr, sep)
    if sep == nil then
        sep = "%s"
    end
    local t = {}
    for str in string.gmatch(inputstr, "([^" .. sep .. "]+)") do
        table.insert(t, str)
    end
    return t
end

-- Calling the function to create the dialog window
createDialog(this)